@@ -83,8 +83,9 @@ gtk_plot_array_get_type (void)
         NULL,
       };
                                                                                 
-      array_type = g_type_register_static (G_TYPE_OBJECT, "GtkPlotArray",
-                                               &array_info, 0);
+      array_type = g_type_register_static (G_TYPE_OBJECT,
+				"GtkPlotArray",
+                                 &array_info, 0);
     }
                                                                                 
   return array_type;
@@ -93,13 +94,10 @@ gtk_plot_array_get_type (void)
 static void
 gtk_plot_array_class_init (GtkPlotArrayClass *klass)
 {
-  GtkPlotArrayClass *array_class;
   GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
   array_parent_class = g_type_class_peek_parent (klass);
 
-  array_class = (GtkPlotArrayClass *) klass;
-
   gobject_class->finalize = gtk_plot_array_finalize;
   gobject_class->set_property = gtk_plot_array_set_property;
   gobject_class->get_property = gtk_plot_array_get_property;
@@ -278,7 +276,7 @@ gtk_plot_array_init (GtkPlotArray *array)
   array->name = NULL;
   array->label = NULL;
   array->description = NULL;
-  array->type = GTK_TYPE_DOUBLE;
+  array->type = G_TYPE_DOUBLE;
   array->own_data = FALSE;
   array->required = FALSE;
   array->independent = FALSE;
@@ -287,7 +285,7 @@ gtk_plot_array_init (GtkPlotArray *array)
 }
 
 GObject*
-gtk_plot_array_new (const gchar *name, gpointer data, gint size, GtkType type, gboolean own_data)
+gtk_plot_array_new (const gchar *name, gpointer data, gint size, GType type, gboolean own_data)
 {
   GObject *object;
 
@@ -352,25 +350,25 @@ gtk_plot_array_set_required(GtkPlotArray *array, gboolean required)
 }
 
 void
-gtk_plot_array_set(GtkPlotArray *array, gpointer data, gint size, GtkType type)
+gtk_plot_array_set(GtkPlotArray *array, gpointer data, gint size, GType type)
 {
   if(array->own_data) gtk_plot_array_free(array);
   array->type = type;
   array->size = size;
   switch(type){
-    case GTK_TYPE_DOUBLE:
+    case G_TYPE_DOUBLE:
       array->data.data_double = (gdouble *)data;
       break;
-    case GTK_TYPE_FLOAT:
+    case G_TYPE_FLOAT:
       array->data.data_float = (gfloat *)data;
       break;
-    case GTK_TYPE_INT:
+    case G_TYPE_INT:
       array->data.data_int = (gint *)data;
       break;
-    case GTK_TYPE_BOOL:
+    case G_TYPE_BOOLEAN:
       array->data.data_bool = (gboolean *)data;
       break;
-    case GTK_TYPE_STRING:
+    case G_TYPE_STRING:
       array->data.data_string = (gchar **)data;
       break;
     default:
@@ -384,23 +382,23 @@ gtk_plot_array_free(GtkPlotArray *array)
   gint i = 0;
 
   switch(array->type){
-    case GTK_TYPE_DOUBLE:
+    case G_TYPE_DOUBLE:
       g_free(array->data.data_double);
       array->data.data_double = NULL;
       break;
-    case GTK_TYPE_FLOAT:
+    case G_TYPE_FLOAT:
       g_free(array->data.data_float);
       array->data.data_float = NULL;
       break;
-    case GTK_TYPE_INT:
+    case G_TYPE_INT:
       g_free(array->data.data_int);
       array->data.data_int = NULL;
       break;
-    case GTK_TYPE_BOOL:
+    case G_TYPE_BOOLEAN:
       g_free(array->data.data_bool);
       array->data.data_bool = NULL;
       break;
-    case GTK_TYPE_STRING:
+    case G_TYPE_STRING:
       for(i = 0; i < array->size; i++)
         if(array->data.data_string && array->data.data_string[i]) 
           g_free(array->data.data_string[i]);
@@ -436,7 +434,7 @@ gtk_plot_array_independent(GtkPlotArray *array)
   return array->independent;
 }
 
-GtkType
+GType
 gtk_plot_array_get_data_type(GtkPlotArray *array)
 {
   return array->type;
@@ -463,42 +461,54 @@ gtk_plot_array_get_description(GtkPlotArray *array)
 gboolean *
 gtk_plot_array_get_bool(GtkPlotArray *array)
 {
-  if(array->type != GTK_TYPE_BOOL) return NULL;
+  if(array->type != G_TYPE_BOOLEAN) return NULL;
   return array->data.data_bool;
 }
 
 gdouble *
 gtk_plot_array_get_double(GtkPlotArray *array)
 {
-  if(array->type != GTK_TYPE_DOUBLE) return NULL;
+  if(array->type != G_TYPE_DOUBLE) return NULL;
   return array->data.data_double;
 }
 
 gfloat *
 gtk_plot_array_get_float(GtkPlotArray *array)
 {
-  if(array->type != GTK_TYPE_FLOAT) return NULL;
+  if(array->type != G_TYPE_FLOAT) return NULL;
   return array->data.data_float;
 }
 
 gint *
 gtk_plot_array_get_int(GtkPlotArray *array)
 {
-  if(array->type != GTK_TYPE_INT) return NULL;
+  if(array->type != G_TYPE_INT) return NULL;
   return array->data.data_int;
 }
 
+/**
+ * gtk_plot_array_get_string:
+ * @array:  the #GtkPlotArray
+ * 
+ * Returns: (transfer none) the data string array
+ */
 gchar **
 gtk_plot_array_get_string(GtkPlotArray *array)
 {
-  if(array->type != GTK_TYPE_STRING) return NULL;
+  if(array->type != G_TYPE_STRING) return NULL;
   return array->data.data_string;
 }
 
+/**
+ * gtk_plot_array_get_pointer:
+ * @array:  the #GtkPlotArray
+ * 
+ * Returns: (transfer none) the data pointer array
+ */
 gpointer *
 gtk_plot_array_get_pointer(GtkPlotArray *array)
 {
-  if(array->type != GTK_TYPE_POINTER) return NULL;
+  if(array->type != G_TYPE_POINTER) return NULL;
   return array->data.data_pointer;
 }
 
@@ -523,8 +533,9 @@ gtk_plot_array_list_get_type (void)
         NULL
       };
                                                                                 
-      array_list_type = g_type_register_static (G_TYPE_OBJECT, "GtkPlotArrayList",
-                                               &data_info, 0);
+      array_list_type = g_type_register_static (G_TYPE_OBJECT, 
+					"GtkPlotArrayList",
+                                         &data_info, 0);
     }
   return array_list_type;
 }
@@ -533,12 +544,10 @@ static void
 gtk_plot_array_list_class_init (GtkPlotArrayListClass *klass)
 {
   GObjectClass *gobject_class;
-  GtkPlotArrayListClass *array_list_class;
 
   array_list_parent_class = g_type_class_peek_parent (klass);
 
   gobject_class = (GObjectClass *) klass;
-  array_list_class = (GtkPlotArrayListClass *) klass;
 
   gobject_class->finalize = gtk_plot_array_list_finalize;
 }
@@ -568,7 +577,7 @@ gtk_plot_array_list_finalize(GObject *object)
   gtk_plot_array_list_clear(array_list);
 }
 
-GList *
+static GList *
 find_array(GtkPlotArrayList *array_list, const gchar *name)
 {
   GList *list;
@@ -611,11 +620,18 @@ gtk_plot_array_list_remove(GtkPlotArrayList *array_list, GtkPlotArray *array)
   }
 }
 
+/**
+ * gtk_plot_array_list_get:
+ * @set: a #GtkPlotArrayList
+ * @name:       the name to be searched for
+ * 
+ * Returns: (transfer none) the named #GtkPlotArray or NULL
+ */
 GtkPlotArray *
-gtk_plot_array_list_get(GtkPlotArrayList *array_list, const gchar *name)
+gtk_plot_array_list_get(GtkPlotArrayList *set, const gchar *name)
 {
   GList *list = NULL;;
-  list = find_array(array_list, name);
+  list = find_array(set, name);
   if(list) return GTK_PLOT_ARRAY(list->data);
   return NULL;
 }
