@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2011 Jiri (George) Lebl
+ * Copyright (C) 1997-2014 Jiri (George) Lebl
  *
  * Author: Jiri (George) Lebl
  *
@@ -29,7 +29,7 @@
 
 #include "structs.h"
 
-#define GENIUS_COPYRIGHT_STRING N_("Copyright (C) 1997-2012 Jiří (George) Lebl, Ph.D.")
+#define GENIUS_COPYRIGHT_STRING N_("Copyright (C) 1997-2014 Jiří (George) Lebl")
 
 typedef enum {
 	GEL_NO_ERROR = 0,
@@ -86,6 +86,10 @@ void	gel_pretty_print_etree	(GelOutput *gelo,
 /* make a newly allocated string for this */
 char *	gel_string_print_etree	(GelETree *n);
 
+/* same as gel_print_etree, but only for function */
+void	gel_print_func (GelOutput *gelo,
+			GelEFunc *f);
+
 /* Note that infile must be gel_lexer_open'ed */
 /*this is the function to be mostly called outsied of calc.c
   evaluate the xpression string and give back a string with the
